/*
 * Copyright (c) 2000 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */


#ifndef __BADGE_DB_DEF_H__
#define __BADGE_DB_DEF_H__

#include <stdbool.h>
#include <sqlite3.h>
#include <sys/types.h>
#include <gio/gio.h>
#include <tzplatform_config.h>
#include <badge_error.h>

#ifdef __cplusplus
extern "C" {
#endif

#define BADGE_DB_PATH tzplatform_mkpath(TZ_SYS_DB, ".badge.db")
#define BADGE_SETTING_DB_TABLE "badge_setting"
#define BADGE_TABLE_NAME "badge_data"
#define BADGE_OPTION_TABLE_NAME "badge_option"

int badge_db_insert(const char *pkgname, const char *writable_pkg, const char *caller, uid_t uid);
int badge_db_delete(const char *pkgname, const char *caller_pkg, uid_t uid, pid_t pid);
int badge_db_delete_by_pkgname(const char *pkgname, uid_t uid);
int badge_db_set_count(const char *pkgname, const char *caller_pkg, unsigned int count, uid_t uid, pid_t pid);
int badge_db_get_count(const char *pkgname, unsigned int *count, uid_t uid);
int badge_db_set_display_option(const char *pkgname, unsigned int is_display, uid_t uid);
int badge_db_get_display_option(const char *pkgname, unsigned int *is_display, uid_t uid);
int badge_db_exec(sqlite3 *db, const char *query, int *num_changes);
int badge_db_get_list(GList **badge_list, uid_t uid);
int badge_db_is_existing(const char *pkgname, bool *existing, uid_t uid);
int badge_db_init();

#ifdef __cplusplus
	}
#endif

#endif /* __BADGE_DB_DEF_H__ */

